@@ -1,5 +1,3 @@
-import pkg_resources
-
 from .prettytable import (
     ALL,
     DEFAULT,
@@ -40,4 +38,11 @@ __all__ = [
     "from_json",
 ]
 
-__version__ = pkg_resources.get_distribution(__name__).version
+try:
+    # Python 3.8+
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    # <Python 3.7 and lower
+    import importlib_metadata
+
+__version__ = importlib_metadata.version(__name__)
